Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/tests/TestScripts/testConfigureDisableStringification.py
diff options
context:
space:
mode:
authorMartin Hořeňovský2025-07-17 13:13:08 +0200
committerMartin Hořeňovský2025-07-17 13:47:44 +0200
commitc22096846c98211e0bcd23dbbd155698fbd718b3 (patch)
tree0d30b3d6a826cd277f559bcb8a217c3e103de444 /tests/TestScripts/testConfigureDisableStringification.py
parentae33e5b99af6f58840f78e1986051b0c6a5823e4 (diff)
downloadcatch3-c22096846c98211e0bcd23dbbd155698fbd718b3.tar.gz
Let reporters opt into fast path in RunContext::assertionStarting
The fast path allows `RunContext` to skip disabling output redirect, and notifying the reporters, turning `RunContext::notifyAssertionStarted` into a no-op. This improves the overall performance of assertion handling significantly, and also prepares ground for future changes around assertion handling and thread safety. For simple 10M assertion run, this improves the running time by ~30% in Debug build and ~40% in Release build. For backwards-compatibility reasons, the fast path is disabled by default. However, none of the first party reporters use the `assertionStarting` event, so all first party reporters are opted-in.
Diffstat (limited to 'tests/TestScripts/testConfigureDisableStringification.py')
0 files changed, 0 insertions, 0 deletions